"""
# Hello

Demonstrate:
* conversion of regular python script into _Jupyter notebook_
* support **Markdown**
* this is a list
"""

from __future__ import absolute_import, print_function, division

"""
## Hello

This is a *hello world* function.

"""


def hello():
    """
    This is a docstring
    """
    print("hello")


"""
## Another Cell 1
"""


def main():
    hello()


"""
### Run this
"""

if __name__ == '__main__':
    def what():
        main()
    print(what())


"""
## Another Cell 2
"""
